"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = inputFileToBase64;
/**
 * Input File to base64
 * ==============================================================================
 *
 * @description This function takes in a *SINGLE* input file from a HTML file input element.
 * HTML file input elements usually return an array of input objects, so be sure to select the target
 * file from the array.
 */
function inputFileToBase64(_a) {
    return __awaiter(this, arguments, void 0, function* ({ inputFile, allowedRegex, }) {
        var _b;
        const allowedTypesRegex = allowedRegex ? allowedRegex : /image\/*|\/pdf/;
        if (!((_b = inputFile === null || inputFile === void 0 ? void 0 : inputFile.type) === null || _b === void 0 ? void 0 : _b.match(allowedTypesRegex))) {
            window.alert(`We currently don't support ${inputFile.type} file types. Support is coming soon. For now we support only images and PDFs.`);
            return {
                fileName: inputFile.name,
            };
        }
        try {
            let fileName = inputFile.name.replace(/\..*/, "");
            const fileData = yield new Promise((resolve, reject) => {
                var reader = new FileReader();
                reader.readAsDataURL(inputFile);
                reader.onload = function () {
                    var _a;
                    resolve((_a = reader.result) === null || _a === void 0 ? void 0 : _a.toString());
                };
                reader.onerror = function (/** @type {*} */ error) {
                    console.log("Error: ", error.message);
                };
            });
            return {
                fileBase64: fileData === null || fileData === void 0 ? void 0 : fileData.replace(/.*?base64,/, ""),
                fileBase64Full: fileData,
                fileName: fileName,
                fileSize: inputFile.size,
                fileType: inputFile.type,
            };
        }
        catch (error) {
            console.log("File Processing Error! =>", error.message);
            return {
                fileName: inputFile.name,
            };
        }
    });
}
