"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = handleGrants;
const noDatabaseDbHandler_1 = __importDefault(require("../utils/noDatabaseDbHandler"));
/**
 * # Handle Grants for Users
 */
function handleGrants(_a) {
    return __awaiter(this, arguments, void 0, function* ({ username, host, grants, userId, }) {
        var _b;
        let success = false;
        console.log(`Handling Grants for User =>`, username, host);
        if (!username) {
            console.log(`No username provided.`);
            return success;
        }
        if (!host) {
            console.log(`No Host provided. \x1b[35m\`--host\`\x1b[0m flag is required`);
            return success;
        }
        if (!grants) {
            console.log(`No grants Array provided.`);
            return success;
        }
        try {
            const existingUser = yield (0, noDatabaseDbHandler_1.default)(`SELECT * FROM mysql.user WHERE User = '${username}' AND Host = '${host}'`);
            const isUserExisting = Boolean((_b = existingUser === null || existingUser === void 0 ? void 0 : existingUser[0]) === null || _b === void 0 ? void 0 : _b.User);
            if (isUserExisting) {
                const userGrants = yield (0, noDatabaseDbHandler_1.default)(`SHOW GRANTS FOR '${username}'@'${host}'`);
                for (let i = 0; i < userGrants.length; i++) {
                    const grantObject = userGrants[i];
                    const grant = grantObject === null || grantObject === void 0 ? void 0 : grantObject[Object.keys(grantObject)[0]];
                    if (grant === null || grant === void 0 ? void 0 : grant.match(/GRANT .* PRIVILEGES ON .* TO/)) {
                        const revokeGrantText = grant
                            .replace(/GRANT/, "REVOKE")
                            .replace(/ TO /, " FROM ");
                        const revokePrivilege = yield (0, noDatabaseDbHandler_1.default)(revokeGrantText);
                    }
                }
                const grantsArray = grants;
                for (let i = 0; i < grantsArray.length; i++) {
                    const grantObject = grantsArray[i];
                    const { database, table, privileges } = grantObject;
                    const tableText = table == "*" ? "*" : `\`${table}\``;
                    const databaseText = database == "*"
                        ? `\`${process.env.DSQL_USER_DB_PREFIX}${userId}_%\``
                        : `\`${database}\``;
                    const privilegesText = privileges.includes("ALL")
                        ? "ALL PRIVILEGES"
                        : privileges.join(", ");
                    const grantText = `GRANT ${privilegesText} ON ${databaseText}.${tableText} TO '${username}'@'${host}'`;
                    const grantPriviledge = yield (0, noDatabaseDbHandler_1.default)(grantText);
                }
            }
            success = true;
        }
        catch ( /** @type {any} */error) {
            console.log(`Error in adding SQL user =>`, error.message);
        }
        return success;
    });
}
